# SEMANTIC PRIMING with high/low frequency targets presented in clear or dim font
# Masson & Kliegl (2013, JEPLMC, Experiment 2): clear and dim trials presented blockwise in counterbalanced order
# 7 May 2011, R. Kliegl

# Exp 2 comprises 16 practice trials and then a break.  
# Then 240 critical with breaks after the 48, 96, 144 and 192 trials.
# Then a break and 16 practice and another break.
# Then another 240 critical with breaks after the 48, 96, 144 and 192 trials.


library(gtools)
library(ggplot2)
library(reshape)
library(lme4)
library(MASS)

rm(list=ls())

# Read raw data; variable names in first line
data <- read.table("data/Exp2_trial_by_trial.txt", header=TRUE)
str(data)

# Levels of subjects not what we want them to be
data$id <- factor(data$id, levels=mixedsort(levels(data$id))) 
# ... mixedsort is from package gtools

# Collect lag information 
Nobs <- nrow(data)
Nlags <- Nobs-1
(ix <- seq(from=1, to=433, by=48))
nolag <- which(data$trial %in% ix)

# Lag-trial "TargetType" information; generate "W" vs. "NW"
data$ltt[2:Nobs] <- data$TargetType[1:Nlags]
data$ltt <- factor(data$ltt, labels=list("RelW", "UnrW", "NW"))

$w <- combine_factor(data$ltt, c(1,1,2) )
levels(data$w) <- c("W", "NW")

# Lag-trial "PrimeRelation" information
data$lpr[2:Nobs] <- data$PrimeRelation[1:Nlags]
data$lpr <- factor(data$lpr, labels=list("Rel", "Unr"))

# Lag-trial "rt" information
data$lrt[2:Nobs] <- data$rt[1:Nlags]

# Lag-trial "score" information
data$lsc[2:Nobs] <- data$score[1:Nlags]
data$lsc <- factor(data$lsc, labels=list("C", "E"))

# Lag-trial item
data$lst[2:Nobs] <- as.character(data$st[1:Nlags])
data$lst <- factor(data$lst)

# Replace missing values with NAs
data[nolag, c("lst", "ltt", "w", "lpr", "lrt", "lsc")] <- NA

# Select data for analyses
d <- subset(data[-nolag, ], TargetType != "NW" &  score=="C") # drop nolags, nonwords, & false resp
d <- droplevels(d)
names(d)[4:6] <- c("q", "f", "p")

# Include covariates (continuous independent variables or predictors)
# ... subject info
id_info <- read.table("data/Exp2_subject_info.txt", header=TRUE)[c(1, 3:5)]  # drop "cc"
id_info$id <- factor(paste("S", id_info$id, sep=""), levels=mixedsort(levels(data$id)))

# ... target info (same as for Exp1)
st_info <- read.table("data/Exp1_target_info.txt", header=TRUE, na.strings=".")[c(1, 5)]

# ... merge infos
d <- merge(d, st_info, by="st")
d <- merge(d, id_info, by="id")

# ... restore trial order within subjects after merge
d <- d[order(d$id, d$trial), ]

# Rename "blockorder" to "b"
names(d)[18] <- "b"

# Contrasts
contrasts(d$q) <- contr.sdif(2)
contrasts(d$f) <- contr.sdif(2)
contrasts(d$p) <- contr.sdif(2)
contrasts(d$w) <- contr.sdif(2)
contrasts(d$b) <- contr.sdif(2)
contrasts(d$lpr) <- contr.sdif(2)
contrasts(d$lsc) <- contr.sdif(2)

# Generate scalars from factors to get at specific variance components
d$Q <- ifelse(d$q == "Clear", -1/2, +1/2)
d$F <- ifelse(d$f == "HF",    -1/2, +1/2)
d$P <- ifelse(d$p == "Rel",   -1/2, +1/2)
d$B <- ifelse(d$b == "CD",    -1/2, +1/2)
d$W <- ifelse(d$w == "W",     -1/2, +1/2)

# ... center trial
d$trial.c <- d$trial - 240  # begin of second half is one

# Transformations 
# ... extreme score removal (four short and three long RTs, final range:xxx-xxxx) 
ibad <- which(d$rt < 300 | d$rt > 2500)
d <- d[-ibad, ]

# ... determine lambda (i.e., power coefficient); boxcox() is from MASS
# ... ... for exact lambda
#lambdaList <- boxcox(rt ~ id*w*e*f*p, data=d)
#lambda <- lambdaList$x[which.max(lambdaList$y)]  # -0.95

# ... alternative DV
d$rrt <- -1000/d$rt  # minus reciprocal of seconds

# ... quick check
boxplot(rt ~ w*p*f*q, data=d)
boxplot(rrt ~ w*p*f*q, data=d)

# Select and resort variables
d <- d[ , c(1, 2, 4, 26, 5:7, 18, 12, 21:25, 16, 11, 13:15, 9, 10, 27)]

# ... remove nolag trials with false responses
d.lsc <- d[d$lsc=="C", ]  # only if last score correct

# Save data
save(data, d, d.lsc, file="Exp2.rda")

